@@ -6,18 +6,19 @@ class Feature(object):
     Tries to import a specific feature.
     """
     Error = factory(['UNSATISFIED_IMPORT_REQ'])
+    _FEATURES = {}
 
     @classmethod
     def import_it(cls):
         """
         Performs the import only once.
         """
-        if not hasattr(cls, '_feature'):
+        if not cls in cls._FEATURES:
             try:
-                cls._feature = cls._import_it()
+                cls._FEATURES[cls] = cls._import_it()
             except ImportError:
                 raise cls.Error(cls._import_error_message(), cls.Error.UNSATISFIED_IMPORT_REQ)
-        return cls._feature
+        return cls._FEATURES[cls]
 
     @classmethod
     def _import_it(cls):
